@@ -18,32 +18,50 @@
 import os
 import sys
 import struct
+import aiohttp
 import platform
+import locale
+import distro
 
 try:
     import raven
+    from raven.transport.http import HTTPTransport
     RAVEN_AVAILABLE = True
 except ImportError:
     # raven is not installed with deb package in order to simplify packaging
     RAVEN_AVAILABLE = False
 
-from .version import __version__
+from .version import __version__, __version_info__
 from .config import Config
+from .utils.get_resource import get_resource
 
 import logging
 log = logging.getLogger(__name__)
 
 
+# Dev build
+if __version_info__[3] != 0:
+    import faulthandler
+
+    # Display a traceback in case of segfault crash. Usefull when frozen
+    # Not enabled by default for security reason
+    log.info("Enable catching segfault")
+    try:
+        faulthandler.enable()
+    except Exception:
+        pass  # Could fail when loaded into tests
+
+
 class CrashReport:
 
     """
     Report crash to a third party service
     """
 
-    DSN = "sync+https://45147533567b4d529ca09c093758681f:12d8b456cdb34d23aba771325aa64ee6@app.getsentry.com/38482"
+    DSN = "https://03a62c6395a54334b0818302138c6555:d7977024b6314ffbaddae057f9bb53b8@sentry.io/38482"
     if hasattr(sys, "frozen"):
-        cacert = os.path.join(os.getcwd(), "cacert.pem")
-        if os.path.isfile(cacert):
+        cacert = get_resource("cacert.pem")
+        if cacert is not None and os.path.isfile(cacert):
             DSN += "?ca_certs={}".format(cacert)
         else:
             log.warning("The SSL certificate bundle file '{}' could not be found".format(cacert))
@@ -52,6 +70,13 @@ class CrashReport:
     def __init__(self):
         self._client = None
 
+        # We don't want sentry making noise if an error is catched when you don't have internet
+        sentry_errors = logging.getLogger('sentry.errors')
+        sentry_errors.disabled = True
+
+        sentry_uncaught = logging.getLogger('sentry.errors.uncaught')
+        sentry_uncaught.disabled = True
+
     def capture_exception(self, request=None):
         if not RAVEN_AVAILABLE:
             return
@@ -61,26 +86,49 @@ class CrashReport:
         server_config = Config.instance().get_section_config("Server")
         if server_config.getboolean("report_errors"):
             if self._client is None:
-                self._client = raven.Client(CrashReport.DSN, release=__version__, raise_send_errors=True)
+                self._client = raven.Client(CrashReport.DSN, release=__version__, raise_send_errors=True, transport=HTTPTransport)
             if request is not None:
                 self._client.http_context({
                     "method": request.method,
                     "url": request.path,
                     "data": request.json,
                 })
-            self._client.tags_context({
+
+            context = {
                 "os:name": platform.system(),
                 "os:release": platform.release(),
                 "os:win_32": " ".join(platform.win32_ver()),
                 "os:mac": "{} {}".format(platform.mac_ver()[0], platform.mac_ver()[2]),
-                "os:linux": " ".join(platform.linux_distribution()),
+                "os:linux": " ".join(distro.linux_distribution()),
+                "aiohttp:version": aiohttp.__version__,
                 "python:version": "{}.{}.{}".format(sys.version_info[0],
                                                     sys.version_info[1],
                                                     sys.version_info[2]),
                 "python:bit": struct.calcsize("P") * 8,
                 "python:encoding": sys.getdefaultencoding(),
                 "python:frozen": "{}".format(hasattr(sys, "frozen"))
-            })
+            }
+
+            if sys.platform.startswith("linux") and not hasattr(sys, "frozen"):
+                # add locale information
+                try:
+                    language, encoding = locale.getlocale()
+                    context["locale:language"] = language
+                    context["locale:encoding"] = encoding
+                except ValueError:
+                    pass
+
+                # add GNS3 VM version if it exists
+                home = os.path.expanduser("~")
+                gns3vm_version = os.path.join(home, ".config", "GNS3", "gns3vm_version")
+                if os.path.isfile(gns3vm_version):
+                    try:
+                        with open(gns3vm_version) as fd:
+                            context["gns3vm:version"] = fd.readline().strip()
+                    except OSError:
+                        pass
+
+            self._client.tags_context(context)
             try:
                 report = self._client.captureException()
             except Exception as e:
