@@ -23,5 +23,15 @@
 # or negative for a release candidate or beta (after the base version
 # number has been incremented)
 
-__version__ = "1.3.3"
-__version_info__ = (1, 3, 3, 0)
+__version__ = "2.2.6"
+__version_info__ = (2, 2, 6, 0)
+
+if "dev" in __version__:
+    try:
+        import os
+        import subprocess
+        if os.path.exists(os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", ".git")):
+            r = subprocess.check_output(["git", "rev-parse", "--short", "HEAD"]).decode().strip("\n")
+            __version__ += "-" + r
+    except Exception as e:
+        print(e)
